==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/sr-CS/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Dodatna Polja',
    'manage'                    => 'Uredi',
    'field'		                => 'Polje',
    'about_fieldsets_title'		=> 'O grupi polja',
    'about_fieldsets_text'		=> 'Skupovi polja vam omogućavaju da kreirate grupe prilagođenih polja koja se često ponovo koriste za određene tipove modela sredstava.',
    'custom_format'             => 'Prilagodljivi Regex format...',
    'encrypt_field'      	        => 'Enkriptujte vrednost polja u bazi podataka',
    'encrypt_field_help'      => 'UPUZORENJE: Nije moguće pretraživati enkriptovana polja.',
    'encrypted'      	        => 'Enkriptovano',
    'fieldset'      	        => 'Grupa polja',
    'qty_fields'      	      => 'Polje količina',
    'fieldsets'      	        => 'Grupa polja',
    'fieldset_name'           => 'Naziv grupa polja',
    'field_name'              => 'Naziv polja',
    'field_values'            => 'Vrednost polja',
    'field_values_help'       => 'Dodajte opcije koje se mogu izabrati, jednu po redu. Prazne linije osim prvog reda će biti zanemarene.',
    'field_element'           => 'Elementi obrasca',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Prilagodljivi Regex format',
    'field_custom_format_help'     => 'Ovo polje Vam omogućava da koristite regex izraz za validaciju. Trebalo bi da počne sa „regex:“ – na primer, da biste potvrdili da vrednost prilagođenog polja sadrži važeći IMEI (15 numeričkih cifara), trebalo bi da koristite <code>regex:/^[0-9]{15}$/< /code>.',
    'required'   		          => 'Obavezno',
    'req'   		              => 'Zah.',
    'used_by_models'   		    => 'Koriste ga modeli',
    'order'   		            => 'Porudžbina',
    'create_fieldset'         => 'Novo Polje',
    'update_fieldset'         => 'Osveži grupu polja',
    'fieldset_does_not_exist'   => 'Grupa polja :id ne postoji',
    'fieldset_updated'         => 'Grupa polja je osvežena',
    'create_fieldset_title' => 'Kreirajte novu grupu polja',
    'create_field'            => 'Novo prilagodjeno polje',
    'create_field_title' => 'Kreirajte prilagođeno polje',
    'value_encrypted'      	        => 'Vrednost ovog polja je šifrovana u bazi podataka. Samo administratori će moći da vide dešifrovanu vrednost',
    'show_in_email'     => 'Uvrsti vrednost ovog polja u e-porukama zaduženja koja se šalju korisnicima? Enkriptovana polja se ne mogu uvrstiti u e-porukama',
    'show_in_email_short'     => 'Uvrsti u e-poruke.',
    'help_text' => 'Pomoćni tekst',
    'help_text_description' => 'Ovo je opcioni tekst koji će se pojaviti ispod elemenata obrasca tokom uređivanja elementa da bi se pružio kontekst na polju.',
    'about_custom_fields_title' => 'O prilagodljivom polju',
    'about_custom_fields_text' => 'Prilagodljiva polja vam omogućavaju da dodate proizvoljne atribute sredstvima.',
    'add_field_to_fieldset' => 'Dodaj polje grupi polja',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Opciono - kliknite da biste učinili obaveznim',
    'reorder' => 'Ponovo Naruči',
    'db_field' => 'Polje u bazi podataka',
    'db_convert_warning' => 'UPOZORENJE. Ovo polje je u tabeli prilagođenih polja kao <code>:db_column</code>, ali bi trebalo da bude <code>:expected</code>.',
    'is_unique' => 'Ova vrednost mora biti jedinstvena za sva sredstva',
    'unique' => 'Jedinstven',
    'display_in_user_view' => 'Dozvoli zaduženom korisniku da vidi ove vrednosti na njihovoj stranici pregleda zadužene imovine',
    'display_in_user_view_table' => 'Vidljivo korisniku',
    'auto_add_to_fieldsets' => 'Automatski dodati ovo svakoj novoj grupi polja',
    'add_to_preexisting_fieldsets' => 'Dodaj svim postojećim grupama polja',
    'show_in_listview' => 'Prikaži podrazumevano u tabelarnim prikazima. Autorizovani korisnici će i dalje moći da prikažu/sakriju putem izbornika kolona',
    'show_in_listview_short' => 'Prikaži u listama',
    'show_in_requestable_list_short' => 'Prikaži u spisku imovine koja se može zatražiti',
    'show_in_requestable_list' => 'Prikaži vrednost u spisku imovine koja se može zatražiti. Enkriptovana polja neće biti prikazana',
    'encrypted_options' => 'Ovo polje je enkriptovano, zato neke opcije prikaza neće biti dostupne.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sr-CS/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Dodatna Polja',
    'manage'                    => 'Uredi',
    'field'		                => 'Polje',
    'about_fieldsets_title'		=> 'O grupi polja',
    'about_fieldsets_text'		=> 'Skupovi polja vam omogućavaju da kreirate grupe prilagođenih polja koja se često ponovo koriste za određene tipove modela sredstava.',
    'custom_format'             => 'Prilagodljivi Regex format...',
    'encrypt_field'      	        => 'Enkriptujte vrednost polja u bazi podataka',
    'encrypt_field_help'      => 'UPUZORENJE: Nije moguće pretraživati enkriptovana polja.',
    'encrypted'      	        => 'Enkriptovano',
    'fieldset'      	        => 'Grupa polja',
    'qty_fields'      	      => 'Polje količina',
    'fieldsets'      	        => 'Grupa polja',
    'fieldset_name'           => 'Naziv grupa polja',
    'field_name'              => 'Naziv polja',
    'field_values'            => 'Vrednost polja',
    'field_values_help'       => 'Dodajte opcije koje se mogu izabrati, jednu po redu. Prazne linije osim prvog reda će biti zanemarene.',
    'field_element'           => 'Elementi obrasca',
    'field_element_short'     => 'Element',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Prilagodljivi Regex format',
    'field_custom_format_help'     => 'Ovo polje Vam omogućava da koristite regex izraz za validaciju. Trebalo bi da počne sa „regex:“ – na primer, da biste potvrdili da vrednost prilagođenog polja sadrži važeći IMEI (15 numeričkih cifara), trebalo bi da koristite <code>regex:/^[0-9]{15}$/< /code>.',
    'required'   		          => 'Obavezno',
    'req'   		              => 'Zah.',
    'used_by_models'   		    => 'Koriste ga modeli',
    'order'   		            => 'Porudžbina',
    'create_fieldset'         => 'Novo Polje',
    'update_fieldset'         => 'Osveži grupu polja',
    'fieldset_does_not_exist'   => 'Grupa polja :id ne postoji',
    'fieldset_updated'         => 'Grupa polja je osvežena',
    'create_fieldset_title' => 'Kreirajte novu grupu polja',
    'create_field'            => 'Novo prilagodjeno polje',
    'create_field_title' => 'Kreirajte prilagođeno polje',
    'value_encrypted'      	        => 'Vrednost ovog polja je šifrovana u bazi podataka. Samo administratori će moći da vide dešifrovanu vrednost',
    'show_in_email'     => 'Uvrsti vrednost ovog polja u e-porukama zaduženja koja se šalju korisnicima? Enkriptovana polja se ne mogu uvrstiti u e-porukama',
    'show_in_email_short' => 'Uvrsti u e-poruke',
    'help_text' => 'Pomoćni tekst',
    'help_text_description' => 'Ovo je opcioni tekst koji će se pojaviti ispod elemenata obrasca tokom uređivanja elementa da bi se pružio kontekst na polju.',
    'about_custom_fields_title' => 'O prilagodljivom polju',
    'about_custom_fields_text' => 'Prilagodljiva polja vam omogućavaju da dodate proizvoljne atribute sredstvima.',
    'add_field_to_fieldset' => 'Dodaj polje grupi polja',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Opciono - kliknite da biste učinili obaveznim',
    'reorder' => 'Ponovo Naruči',
    'db_field' => 'Polje u bazi podataka',
    'db_convert_warning' => 'UPOZORENJE. Ovo polje je u tabeli prilagođenih polja kao <code>:db_column</code>, ali bi trebalo da bude <code>:expected</code>.',
    'is_unique' => 'Ova vrednost mora biti jedinstvena za sva sredstva',
    'unique' => 'Jedinstven',
    'display_in_user_view' => 'Dozvoli zaduženom korisniku da vidi ove vrednosti na njihovoj stranici pregleda zadužene imovine',
    'display_in_user_view_table' => 'Vidljivo korisniku',
    'auto_add_to_fieldsets' => 'Automatski dodati ovo svakoj novoj grupi polja',
    'add_to_preexisting_fieldsets' => 'Dodaj svim postojećim grupama polja',
    'show_in_listview' => 'Prikaži podrazumevano u tabelarnim prikazima. Autorizovani korisnici će i dalje moći da prikažu/sakriju putem izbornika kolona',
    'show_in_listview_short' => 'Prikaži u listama',
    'show_in_requestable_list_short' => 'Prikaži u spisku imovine koja se može zatražiti',
    'show_in_requestable_list' => 'Prikaži vrednost u spisku imovine koja se može zatražiti. Enkriptovana polja neće biti prikazana',
    'encrypted_options' => 'Ovo polje je enkriptovano, zato neke opcije prikaza neće biti dostupne.',
    'display_checkin' => 'Prikaži u formularima razduživanja',
    'display_checkout' => 'Prikaži u formularima zaduživanja',

];
